@@ -15,8 +15,8 @@ def _email_to_username(email):
     # Emails should be case-insensitive unique
     email = email.lower()
     # Deal with internationalized email addresses
-    converted = email.encode('utf8', 'ignore').digest()
-    return base64.urlsafe_b64encode(hashlib.sha256(converted))[:30]
+    converted = email.encode('utf8', 'ignore')
+    return base64.urlsafe_b64encode(hashlib.sha256(converted).digest())[:30]
 
 
 def get_user(email, queryset=None):
